@@ -247,11 +247,12 @@ void TreeDrawSphere::draw(Point3D *viewer, bool viewculling, QGLWidget *widget,
 #ifdef EARTH3DDEBUG
     printf("tex 1\n");
 #endif
-#ifdef USE_GL_TEXTURE_COMPRESSION
-    glTexImage2D(GL_TEXTURE_2D, 0, GL_COMPRESSED_RGBA_ARB, img.width(), img.height(), 0, GL_RGBA, GL_UNSIGNED_BYTE, img.bits());
-#else
-    glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA8, img.width(), img.height(), 0, GL_RGBA, GL_UNSIGNED_BYTE, img.bits());
-#endif
+    if (cacheUseTextureCompression) {
+      glTexImage2D(GL_TEXTURE_2D, 0, GL_COMPRESSED_RGBA_ARB, img.width(), img.height(), 0, GL_RGBA, GL_UNSIGNED_BYTE, img.bits());
+    }
+    else {
+      glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA8, img.width(), img.height(), 0, GL_RGBA, GL_UNSIGNED_BYTE, img.bits());
+    }
 	  
     glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR);	// Linear Filtering
     glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);	// Linear Filtering
@@ -492,11 +493,13 @@ void TreeDrawSphere::bindSingleGLTexture(int textureid, int width, int height, c
 #ifdef EARTH3DDEBUG
   printf("tex 2\n");
 #endif
-#ifdef USE_GL_TEXTURE_COMPRESSION
-  glTexImage2D(GL_TEXTURE_2D, 0, GL_COMPRESSED_RGB_ARB, width, height, 0, GL_RGB, GL_UNSIGNED_BYTE, image);
-#else
-  glTexImage2D(GL_TEXTURE_2D, 0, GL_RGB8, width, height, 0, GL_RGB, GL_UNSIGNED_BYTE, image);
-#endif
+
+  if (cacheUseTextureCompression) {
+    glTexImage2D(GL_TEXTURE_2D, 0, GL_COMPRESSED_RGB_ARB, width, height, 0, GL_RGB, GL_UNSIGNED_BYTE, image);
+  }
+  else {
+    glTexImage2D(GL_TEXTURE_2D, 0, GL_RGB8, width, height, 0, GL_RGB, GL_UNSIGNED_BYTE, image);
+  }
 
   glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_LINEAR);	// Linear Filtering
   glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_LINEAR);	// Linear Filtering
@@ -634,19 +637,25 @@ void TreeDrawSphere::drawNodes(vector<MapTileTreeNode *> *selectedNodes, bool te
       glEnable(GL_COLOR_MATERIAL);
       glColor4f(1.f, 1.f, 1.f, 1.f);
 
-      glActiveTextureARB(GL_TEXTURE1_ARB);
-      glClientActiveTextureARB(GL_TEXTURE1_ARB);
-      glEnable(GL_TEXTURE_2D);
-      glEnableClientState(GL_TEXTURE_COORD_ARRAY);
+      /* Set second texture only if the user wants multitexturing */
+      if (cacheUseMultiTexturing) {
+	glActiveTextureARB(GL_TEXTURE1_ARB);
+	glClientActiveTextureARB(GL_TEXTURE1_ARB);
+	glEnable(GL_TEXTURE_2D);
+	glEnableClientState(GL_TEXTURE_COORD_ARRAY);
       
-      int interpolationtextureID = core->getInterpolationTextureID();
-      if (interpolationtextureID==0) {
-	blendvalue = 0;
+	int interpolationtextureID = core->getInterpolationTextureID();
+	if (interpolationtextureID==0) {
+	  blendvalue = 0;
+	}
+	else {
+	  glColor4f(blendvalue, blendvalue, blendvalue, 1.f);
+	  glEnable(GL_TEXTURE_2D);
+	  glBindTexture(GL_TEXTURE_2D, interpolationtextureID);
+	}
       }
       else {
-	glColor4f(blendvalue, blendvalue, blendvalue, 1.f);
-	glEnable(GL_TEXTURE_2D);
-	glBindTexture(GL_TEXTURE_2D, interpolationtextureID);
+	blendvalue = 0;
       }
 
       for(int row=0; row<hcore->vertexcount/hcore->stripsize; row++) {
@@ -712,18 +721,31 @@ void TreeDrawSphere::drawNodes(vector<MapTileTreeNode *> *selectedNodes, bool te
 	  }
 #endif
 
-	  for(int vertexnr=0; vertexnr<hcore->fansize[direction][fan]; vertexnr++) {
-#ifdef NO_MULTITEXTURE
-	    glNormal3f(vertex->x, vertex->y, vertex->z); glTexCoord2f(texcoord->x, texcoord->y); /* glTexCoord2f((1./(hcore->tile.width-1))*x, (1./(hcore->tile.height-1))*row); */ glVertex3f(vertex->x, vertex->y, vertex->z);
-#else
-	    glNormal3f(vertex->x, vertex->y, vertex->z); 
-	    glMultiTexCoord2fARB(GL_TEXTURE0_ARB, texcoord->x, texcoord->y);
-	    glMultiTexCoord2fARB(GL_TEXTURE1_ARB, texcoord->x, texcoord->y);
-	    GLVERTEX3D(vertex->x, vertex->y, vertex->z);
-#endif
-	    vertex++;
-	    texcoord++;
+	  if (cacheUseMultiTexturing) {
+	    for(int vertexnr=0; vertexnr<hcore->fansize[direction][fan]; vertexnr++) {
+
+	      glNormal3f(vertex->x, vertex->y, vertex->z); 
+	      glMultiTexCoord2fARB(GL_TEXTURE0_ARB, texcoord->x, texcoord->y);
+	      glMultiTexCoord2fARB(GL_TEXTURE1_ARB, texcoord->x, texcoord->y);
+	      GLVERTEX3D(vertex->x, vertex->y, vertex->z);
+
+	      vertex++;
+	      texcoord++;
+	    }
 	  }
+	  else {
+	    for(int vertexnr=0; vertexnr<hcore->fansize[direction][fan]; vertexnr++) {
+
+	      glNormal3f(vertex->x, vertex->y, vertex->z); 
+	      glTexCoord2f(texcoord->x, texcoord->y); 
+	      /* glTexCoord2f((1./(hcore->tile.width-1))*x, (1./(hcore->tile.height-1))*row); */ 
+	      glVertex3f(vertex->x, vertex->y, vertex->z);
+
+	      vertex++;
+	      texcoord++;
+	    }
+	  }
+
 	  glEnd();
 	}
       }
