@@ -104,6 +104,30 @@ bool FormOptions::getUseLocalCaching() {
   return(checkBoxUseLocalCache->isChecked());
 }
 
+void FormOptions::setRotationType( int type ) {
+  switch(type) {
+  case 0:
+    radioButtonFrontPoint->setChecked(true);
+    break;
+  case 1:
+    radioButtonAroundCamera->setChecked(true);
+    break;
+  default:
+    radioButtonFrontPoint->setChecked(true);
+  }
+}
+
+int FormOptions::getRotationType() {
+  if (radioButtonFrontPoint->isChecked()) {
+    return 0;
+  }
+  if (radioButtonAroundCamera->isChecked()) {
+    return 1;
+  }
+
+  return 0;
+}
+
 void FormOptions::setLocalCacheSize( int size_mb ) {
   lineEditCacheSizeMB->setText( QString::number(size_mb) );
 }
