@@ -139,7 +139,7 @@ void FormView::init()
 
   /* init global variables */
   maptiledrawtype = 0;
-  heightfieldmultiplier =  6378140. / EARTHRADIUS;
+  heightfieldmultiplier =  4;
   concurrentdownloads = 10;
   serviceListLocation = "http://www.earth3d.org/earth3daddresses.xml";
 }
@@ -415,8 +415,11 @@ void FormView::optionsSlot()
   fo.setLocalCacheSize(getAttribute("cachesize", "50").toInt());
   fo.setLocalCacheLocation(getAttribute("cachelocation", QDir::homeDirPath()+QDir::separator()+QString(".earth3d")+QDir::separator()+QString("cache")));
   fo.setLocalCacheUsage(fileCache.getUsedSizeMB(), getAttribute("cachesize", "50").toInt());
+  fo.setRotationType(getAttribute("rotationtype").toInt());
 
+  cout << "exec" << endl;
   int result = fo.exec();
+  cout << "exec2" << endl;
   if (result==QDialog::Accepted) {
     /* read new values */
     heightfieldmultiplier = fo.getHeightfieldMultiplier();
@@ -431,6 +434,7 @@ void FormView::optionsSlot()
     setAttribute("usecache", fo.getUseLocalCaching() ? "true":"false");
     setAttribute("cachesize", QString::number(fo.getLocalCacheSize()));
     setAttribute("cachelocation", fo.getLocalCacheLocation());
+    setAttribute("rotationtype", QString::number(fo.getRotationType()));
 
     saveAttributes();
     loadCachedAttributes();
