@@ -1,6 +1,7 @@
 #ifndef GLOBALSETTINGS_H
 #define GLOBALSETTINGS_H
 #include <qapplication.h>
+#include "fileCache.h"
 
 class FormView;
 
@@ -11,7 +12,7 @@ typedef double DOUBLE;
 #endif
 
 #define GLDOUBLE GL_DOUBLE
-#define GLVERTEX3D glVertex3d
+#define GLVERTEX3D glVertex3f
 
 extern float MAXTILESIZE;
 extern float CENTERWEIGHT;
@@ -49,12 +50,21 @@ extern int concurrentdownloads;
 
 extern QMap<QString, QString> configAttributesMap;
 
+/* to prevent calling getAttributes once per frame, we cache two attributes here */
+extern bool cacheUseMultiTexturing;
+extern bool cacheUseTextureCompression;
+
+/* local file cache */
+extern FileCache fileCache;
+
 // Functions to read the earth3d.xml configuration file from the main directory.
 
 void readXMLConfig(QString path);
 bool isAttributeExisting(QString attr);
 QString getAttribute(QString attr);
+QString getAttribute(QString attr, QString defaultvalue);
 void setAttribute(QString attr, QString value);
 void saveAttributes();
+void loadCachedAttributes();
 
 #endif
