@@ -523,8 +523,14 @@ void GLTestWidget::mouseMoveEvent(QMouseEvent * e) {
       my = e->y();
       
       /* rotate around */
-      nav.rotateOnSurface(mx-omx);
-      nav.elevate(omy-my);
+      if (getAttribute("rotationtype")=="1") {
+	nav.rotateOnSurface(mx-omx);
+	nav.elevate(omy-my);
+      }
+      else {
+	nav.rotateOnPointH(mx-omx);
+	nav.rotateOnPointV(omy-my);
+      }
 
       updateScreen();
     }
@@ -625,22 +631,42 @@ void GLTestWidget::keyPressEvent (QKeyEvent * e) {
     return;
   }
   if (e->key()==Qt::Key_Right) {
-    nav.rotate(-5);
+    if (getAttribute("rotationtype")=="1") {
+      nav.rotate(-5);
+    }
+    else {
+      nav.rotateOnPointH(-5);
+    }
     updateScreen();
     return;
   }
   if (e->key()==Qt::Key_Left) {
-    nav.rotate(5);
+    if (getAttribute("rotationtype")=="1") {
+      nav.rotate(5);
+    }
+    else {
+      nav.rotateOnPointH(5);
+    }
     updateScreen();
     return;
   }
   if (e->key()==Qt::Key_Up) {
-    nav.elevate(-5);
+    if (getAttribute("rotationtype")=="1") {
+      nav.elevate(-5);
+    }
+    else {
+      nav.rotateOnPointV(-5);
+    }
     updateScreen();
     return;
   }
   if (e->key()==Qt::Key_Down) {
-    nav.elevate(5);
+    if (getAttribute("rotationtype")=="1") {
+      nav.elevate(5);
+    }
+    else {
+      nav.rotateOnPointV(5);
+    }
     updateScreen();
     return;
   }
