@@ -2,7 +2,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-ConnectNetworkServiceRequestQueueObject::ConnectNetworkServiceRequestQueueObject(const char *xmlconnection, DataReceivedListener *drl, void *userdata, int timeout) {
+ConnectNetworkServiceRequestQueueObject::ConnectNetworkServiceRequestQueueObject(const char *xmlconnection, DataReceivedListener *drl, void *userdata, int timeout, bool allowCache) {
   if (xmlconnection) {
     this->xmlconnection = new char[strlen(xmlconnection)+1];
     strcpy(this->xmlconnection, xmlconnection);
@@ -13,6 +13,8 @@ ConnectNetworkServiceRequestQueueObject::ConnectNetworkServiceRequestQueueObject
   this->drl = drl;
   this->userdata = userdata;
   this->timeout = timeout;
+  this->messageid = 0;
+  this->allowCache = allowCache;
 }
 
 ConnectNetworkServiceRequestQueueObject::~ConnectNetworkServiceRequestQueueObject() {
@@ -35,3 +37,18 @@ void *ConnectNetworkServiceRequestQueueObject::getUserData() {
   return(userdata);
 }
 
+int ConnectNetworkServiceRequestQueueObject::getMessageID() {
+  return(messageid);
+} 
+
+void ConnectNetworkServiceRequestQueueObject::setMessageID(int messageid) {
+  this->messageid = messageid;
+}
+
+bool ConnectNetworkServiceRequestQueueObject::getAllowCache() {
+  return(allowCache);
+}
+
+void ConnectNetworkServiceRequestQueueObject::setAllowCache(bool allowCache) {
+  this->allowCache = allowCache;
+}
