@@ -10,9 +10,11 @@ class ConnectNetworkServiceRequestQueueObject {
   DataReceivedListener *drl;
   void *userdata;
   int timeout;
-  
+  int messageid;
+  bool allowCache;
+
 public:
-  ConnectNetworkServiceRequestQueueObject(const char *xmlconnection, DataReceivedListener *drl, void *userdata, int timeout);
+  ConnectNetworkServiceRequestQueueObject(const char *xmlconnection, DataReceivedListener *drl, void *userdata, int timeout, bool allowCache);
   ~ConnectNetworkServiceRequestQueueObject();
 
   int getTimeout();
@@ -22,6 +24,13 @@ public:
   DataReceivedListener *getDataReceivedListener();
 
   void *getUserData();
+
+  int getMessageID();
+  void setMessageID(int messageid);
+
+  /** Returns if this download permits caching using the local cache. The proxy cache is always allowed. */
+  bool getAllowCache();
+  void setAllowCache(bool allowCache);
 };
 
 #endif
