@@ -10,6 +10,7 @@ class ProxyUrlOperator : public QObject {
   QString url;
   QHttp* http;
   int downloadid;
+  bool allowCache;
 
  signals:
   void finished(QNetworkOperation *qn);
@@ -25,7 +26,7 @@ class ProxyUrlOperator : public QObject {
    virtual void dataReadProgress ( int done, int total );
 
  public:
-  ProxyUrlOperator(const char *url);
+  ProxyUrlOperator(const char *url, bool allowCache=true);
   virtual ~ProxyUrlOperator();
 
   virtual const QNetworkOperation * get ( const QString & location = QString::null );
