@@ -1,7 +1,7 @@
 #include "urlRawDownload.h"
 
 URLRawDownload::URLRawDownload(const char *url, DataReceivedListener *drl, void *userdata, bool allowCache) 
-: URLDownload(url, drl, userdata) {
+: URLDownload(url, drl, userdata, allowCache) {
 }
 
 URLRawDownload::~URLRawDownload() {
