@@ -9,7 +9,7 @@ class ServiceListDownload : public DataReceivedListener {
   FormView *formview;
 
  public:
-  ServiceListDownload(const char *url, FormView *formview);
+  ServiceListDownload(QString url, FormView *formview);
   ~ServiceListDownload();
 
   virtual void dataReceived(const char *response, int size, const char *sender, int countParts, struct part_t *parts, void *userdata, ConnectNetworkService *cns, StopableDownload *download);
