@@ -1,4 +1,4 @@
 #include "mutex.h"
 
-QMutex treelock;
+QMutex treelock(true);
 
